<?php

namespace Hrm\Disciplinary\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Hrm\Disciplinary\Http\Requests\DisciplinaryRequest;
use Hrm\Disciplinary\Interfaces\DisciplinaryRepositoryInterface;
use Hrm\Disciplinary\Models\Disciplinary;
use Hrm\Disciplinary\Forms\Disciplinary as Form;

/**
 * APIController  class for disciplinary.
 */
class DisciplinaryAPIController extends BaseController
{

    /**
     * Initialize disciplinary resource controller.
     *
     * @param type DisciplinaryRepositoryInterface $disciplinary
     *
     * @return null
     */
    public function __construct(DisciplinaryRepositoryInterface $disciplinary)
    {
        parent::__construct();
        $this->repository = $disciplinary;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Hrm\Disciplinary\Repositories\Criteria\DisciplinaryResourceCriteria::class);
    }

    /**
     * Display a list of disciplinary.
     *
     * @return Response
     */
    public function index(DisciplinaryRequest $request)
    {
        return $this->repository
            ->setPresenter(\Hrm\Disciplinary\Repositories\Presenter\DisciplinaryPresenter::class)
            ->paginate();
    }

    /**
     * Display disciplinary.
     *
     * @param Request $request
     * @param Model   $disciplinary
     *
     * @return Response
     */
    public function show(DisciplinaryRequest $request, Disciplinary $disciplinary)
    {
        return $disciplinary->setPresenter(\Hrm\Disciplinary\Repositories\Presenter\DisciplinaryListPresenter::class);
        ;
    }

    /**
     * Create new disciplinary.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DisciplinaryRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('disciplinary::disciplinary.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('disciplinary/disciplinary/' . $disciplinary->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('disciplinary/disciplinary');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the disciplinary.
     *
     * @param Request $request
     * @param Model   $disciplinary
     *
     * @return Response
     */
    public function update(DisciplinaryRequest $request, Disciplinary $disciplinary)
    {
        try {
            $data = $request->all();

            $disciplinary->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('disciplinary::disciplinary.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('disciplinary/disciplinary/' . $disciplinary->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('disciplinary/disciplinary/' . $disciplinary->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the disciplinary.
     *
     * @param Model   $disciplinary
     *
     * @return Response
     */
    public function destroy(DisciplinaryRequest $request, Disciplinary $disciplinary)
    {
        try {
            $disciplinary->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('disciplinary::disciplinary.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('disciplinary/disciplinary/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('disciplinary/disciplinary/' . $disciplinary->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
