<?php

namespace Hrm\Disciplinary\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Disciplinary\Models\DisciplinaryCategory;

class DisciplinaryCategoryPolicy
{

    /**
     * Determine if the given user can view the disciplinary_category.
     *
     * @param UserPolicy $user
     * @param DisciplinaryCategory $disciplinary_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, DisciplinaryCategory $disciplinary_category)
    {
        if ($user->canDo('disciplinary.disciplinary_category.view') && $user->isAdmin()) {
            return true;
        }

        return $disciplinary_category->user_id == user_id() && $disciplinary_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a disciplinary_category.
     *
     * @param UserPolicy $user
     * @param DisciplinaryCategory $disciplinary_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('disciplinary.disciplinary_category.create');
    }

    /**
     * Determine if the given user can update the given disciplinary_category.
     *
     * @param UserPolicy $user
     * @param DisciplinaryCategory $disciplinary_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, DisciplinaryCategory $disciplinary_category)
    {
        if ($user->canDo('disciplinary.disciplinary_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $disciplinary_category->user_id == user_id() && $disciplinary_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given disciplinary_category.
     *
     * @param UserPolicy $user
     * @param DisciplinaryCategory $disciplinary_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, DisciplinaryCategory $disciplinary_category)
    {
        return $disciplinary_category->user_id == user_id() && $disciplinary_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given disciplinary_category.
     *
     * @param UserPolicy $user
     * @param DisciplinaryCategory $disciplinary_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, DisciplinaryCategory $disciplinary_category)
    {
        if ($user->canDo('disciplinary.disciplinary_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given disciplinary_category.
     *
     * @param UserPolicy $user
     * @param DisciplinaryCategory $disciplinary_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, DisciplinaryCategory $disciplinary_category)
    {
        if ($user->canDo('disciplinary.disciplinary_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
