<?php

namespace Hrm\Disciplinary\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Disciplinary\Models\Disciplinary;

class DisciplinaryPolicy
{

    /**
     * Determine if the given user can view the disciplinary.
     *
     * @param UserPolicy $user
     * @param Disciplinary $disciplinary
     *
     * @return bool
     */
    public function view(UserPolicy $user, Disciplinary $disciplinary)
    {
        if ($user->canDo('disciplinary.disciplinary.view') && $user->isAdmin()) {
            return true;
        }

        return $disciplinary->user_id == user_id() && $disciplinary->user_type == user_type();
    }

    /**
     * Determine if the given user can create a disciplinary.
     *
     * @param UserPolicy $user
     * @param Disciplinary $disciplinary
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('disciplinary.disciplinary.create');
    }

    /**
     * Determine if the given user can update the given disciplinary.
     *
     * @param UserPolicy $user
     * @param Disciplinary $disciplinary
     *
     * @return bool
     */
    public function update(UserPolicy $user, Disciplinary $disciplinary)
    {
        if ($user->canDo('disciplinary.disciplinary.edit') && $user->isAdmin()) {
            return true;
        }

        return $disciplinary->user_id == user_id() && $disciplinary->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given disciplinary.
     *
     * @param UserPolicy $user
     * @param Disciplinary $disciplinary
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Disciplinary $disciplinary)
    {
        return $disciplinary->user_id == user_id() && $disciplinary->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given disciplinary.
     *
     * @param UserPolicy $user
     * @param Disciplinary $disciplinary
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Disciplinary $disciplinary)
    {
        if ($user->canDo('disciplinary.disciplinary.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given disciplinary.
     *
     * @param UserPolicy $user
     * @param Disciplinary $disciplinary
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Disciplinary $disciplinary)
    {
        if ($user->canDo('disciplinary.disciplinary.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
