<?php

namespace Hrm\Disciplinary\Providers;

use Illuminate\Support\ServiceProvider;

class DisciplinaryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'disciplinary');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'disciplinary');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerDisciplinary();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerDisciplinary()
    {
        $this->app->bind('disciplinary', function($app) {
            return new Disciplinary($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Disciplinary', 'Lavalite\Disciplinary\Facades\Disciplinary');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('hrm.disciplinary', function ($app) {
            return $this->app->make('Hrm\Disciplinary\Disciplinary');
        });

        // Bind Disciplinary to repository
        $this->app->bind(
            'Hrm\Disciplinary\Interfaces\DisciplinaryRepositoryInterface',
            \Hrm\Disciplinary\Repositories\Eloquent\DisciplinaryRepository::class
        );
        // Bind DisciplinaryCategory to repository
        $this->app->bind(
            'Hrm\Disciplinary\Interfaces\DisciplinaryCategoryRepositoryInterface',
            \Hrm\Disciplinary\Repositories\Eloquent\DisciplinaryCategoryRepository::class
        );

        $this->app->register(\Hrm\Disciplinary\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Hrm\Disciplinary\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and disciplinary's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'hrm.disciplinary'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeDisciplinary::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['hrm.disciplinary'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('hrm/disciplinary.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/disciplinary')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/disciplinary')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
