<?php

namespace Hrm\Disciplinary\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Hrm\Disciplinary\Models\Disciplinary;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Hrm\Disciplinary\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/disciplinary/disciplinary/*')) {
            Route::bind('disciplinary', function ($disciplinary) {
                $disciplinaryrepo = $this->app->make('Hrm\Disciplinary\Interfaces\DisciplinaryRepositoryInterface');
                return $disciplinaryrepo->findorNew($disciplinary);
            });
        }

        if (Request::is('*/disciplinary/disciplinary_category/*')) {
            Route::bind('disciplinary_category', function ($disciplinary_category) {
                $disciplinary_categoryrepo = $this->app->make('Hrm\Disciplinary\Interfaces\DisciplinaryCategoryRepositoryInterface');
                return $disciplinary_categoryrepo->findorNew($disciplinary_category);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
